<?php

namespace Drupal\pluggable_entity_view_builder;

/**
 * Helper methods to wrap output in a wrapper and container classes.
 */
trait ComponentWrapTrait {

  /**
   * Wrap a component with a container class, and some identifier class.
   *
   * @param array $element
   *   The renderable array of the element which is the component.
   * @param string $wrapper_class_name
   *   The class name to wrap the element with. The identifier class is mainly
   *   used to distinguish the component on the phpunit tests.
   * @param string $container_class_name
   *   Optional; To allow each component to define their own container we allow
   *   defining the type of the container (e.g. a TailWind container such as
   *   `fluid-container-narrow`). We have a distinction between this variable
   *   and teh wrapper class name, so it's clear one if for identification, and
   *   one is for layout.
   *
   * @return array
   *   Render array.
   */
  protected function wrapComponentWithContainer(array $element, string $wrapper_class_name, string $container_class_name = NULL) {
    $build = [];
    $build['container'] = [
      '#type' => 'container',
    ];

    if ($wrapper_class_name) {
      $build['container']['#attributes']['class'][] = $wrapper_class_name;
    }

    if ($container_class_name) {
      $build['container']['#attributes']['class'][] = $container_class_name;
    }

    $build['container']['element'] = $element;

    return $build;
  }

}
